@@ -26,7 +26,7 @@ make_reduced_basis_map <- function(x_basis, reduce_basis_crit) {
   assertthat::assert_that(reduce_basis_crit < 1 && reduce_basis_crit > 0)
 
   # filter over the matrix of basis functions
-  basis_filled_prop <- get_pnz(x_basis)
+  basis_filled_prop <- calc_pnz(x_basis)
   reduced_basis_col_ind <- which(basis_filled_prop > reduce_basis_crit)
   return(reduced_basis_col_ind)
 }
